@@ -9,6 +9,14 @@ import random
 import torch
 import cv2
 
+import sys
+from pathlib import Path
+
+FILE = Path(__file__).resolve()
+ROOT = FILE.parents[0]  
+if str(ROOT) not in sys.path:
+    sys.path.append(str(ROOT))  
+    
 class Yolor:
     def __init__(
         self, 
